const express = require('express');
const multer = require('multer');
const path = require('path');
const router = express.Router();
const {nanoid} = require('nanoid');
const config = require('./config');
const Product = require('./models/Products');
const User = require("./models/User");
const auth = require('./middleware/auth');

    const storage = multer.diskStorage({
        destination: (req, file, cb) => {
            cb(null, config.uploadPath);
        },
        filename: (req, file, cb) => {
            cb(null, nanoid() + path.extname(file.originalname))
        }
    });
    const upload = multer({storage});

const createRouter = () => {
    router.get('/', async (req, res) => {
        let filter = {};
        if(req.query.category){
            filter.category = req.query.category;
        }
        try {
            const products = await Product.find(filter).populate('category', '_id title');
            res.send(products);
        } catch (e) {
            res.status(500).send(e);
        }
    });

    router.get('/:id', async (req, res) => {
       try {
           const result = await Product.findById(req.params.id);
           res.send(result);
       }catch (e) {
           res.sendStatus(404);
       }
    });

    router.post('/', auth, upload.single('image'), async (req, res) => {
        const product = new Product(req.body);
        if(req.file) {
            product.image = req.file.filename;
        }
        product.user = user._id;
        try {
            await product.save();
            res.send(product);
        } catch (e) {
            res.status(500).send(e);
        }
    });

    return router;
};


module.exports = createRouter;