const config = require("./app/config");
const mongoose = require("mongoose");
const Category = require("./app/models/Category");
const Products = require("./app/models/Products");
const User = require("./app/models/User");
const {nanoid} = require("nanoid");

mongoose.connect(config.db.url + '/' + config.db.name);
const db = mongoose.connection;

db.once('open', async () => {
    try {
        await db.dropCollection('categories');
        await db.dropCollection('products');
        await db.dropCollection('users');
    } catch (e) {
        console.log('Collections not found, skipping drop...');
    }

    const [cpuCategory, hddCategory] = await Category.create({
        title: "CPUs",
        description: "Central Processor Units"
    }, {
        title: "HDDs",
        description: "Hard Disk Drives"
    });

    await Products.create({
        title: "Intel core i7",
        price: 500,
        category: cpuCategory._id,
        image: "cpu.jpeg"
    }, {
        title: "Seagate Barracuda 2TB",
        price: 350,
        category: hddCategory._id,
        image: "hdd.jpeg"
    });

    await User.create({
        username: 'admin',
        email: 'admin@admin.com',
        password: '123456',
        token: nanoid()
    }, {
        username: 'user',
        email: 'user@user.com',
        password: '123456',
        token: nanoid()
    })

    await db.close();
});